@@ -1,7 +1,7 @@
 package App::btcindo;
 
 our $DATE = '2018-02-01'; # DATE
-our $VERSION = '0.018'; # VERSION
+our $VERSION = '0.019'; # VERSION
 
 use 5.010001;
 use strict;
@@ -244,7 +244,8 @@ $SPEC{ticker} = {
     v => 1.1,
     summary => 'Show ticker',
     args => {
-        %arg_0_pair,
+        # currently only btc_idr is provided by the API so we comment this out
+        #%arg_0_pair,
     },
 };
 sub ticker {
@@ -1057,7 +1058,7 @@ App::btcindo - CLI for bitcoin.co.id (VIP)
 
 =head1 VERSION
 
-This document describes version 0.018 of App::btcindo (from Perl distribution App-btcindo), released on 2018-02-01.
+This document describes version 0.019 of App::btcindo (from Perl distribution App-btcindo), released on 2018-02-01.
 
 =head1 SYNOPSIS
 
@@ -1548,21 +1549,13 @@ Return value:  (any)
 
 Usage:
 
- ticker(%args) -> [status, msg, result, meta]
+ ticker() -> [status, msg, result, meta]
 
 Show ticker.
 
 This function is not exported.
 
-Arguments ('*' denotes required arguments):
-
-=over 4
-
-=item * B<pair> => I<str> (default: "btc_idr")
-
-Pair.
-
-=back
+No arguments.
 
 Returns an enveloped result (an array).
 
